@@ -1,5 +1,7 @@
-from abc import ABC,abstractmethod
-__author__ = 'Mael Guilleme mael.guilleme[at]irisa.fr'
+from abc import ABC, abstractmethod
+
+__author__ = "Mael Guilleme mael.guilleme[at]irisa.fr"
+
 
 class NeighborsGenerator(ABC):
     """
@@ -14,7 +16,7 @@ class NeighborsGenerator(ABC):
         pass
 
     @abstractmethod
-    def generate(self,nb_features,nb_neighbors,transform):
+    def generate(self, nb_features, nb_neighbors, transform):
         """
         Generate neighbors and the kernel weights of the neighbors around the explained instance.
 
@@ -26,4 +28,4 @@ class NeighborsGenerator(ABC):
         Returns:
             neighbors (Neighbors): the neighbors.
         """
-        pass
\ No newline at end of file
+        pass
