@@ -1,6 +1,9 @@
-from TSInterpret.InterpretabilityModels.leftist.timeseries.segmentator.segmentator import Segmentator
+from TSInterpret.InterpretabilityModels.leftist.timeseries.segmentator.segmentator import (
+    Segmentator,
+)
+
+__author__ = "Mael Guilleme mael.guilleme[at]irisa.fr"
 
-__author__ = 'Mael Guilleme mael.guilleme[at]irisa.fr'
 
 class ProvidedSegmentator(Segmentator):
     """
@@ -17,7 +20,7 @@ class ProvidedSegmentator(Segmentator):
         Segmentator.__init__(self)
         self.segments = segments
 
-    def segment(self,time_series):
+    def segment(self, time_series):
         """
         Segment the time series.
 
@@ -26,5 +29,3 @@ class ProvidedSegmentator(Segmentator):
         """
 
         return len(self.segments), self.segments
-
-
