@@ -1,6 +1,7 @@
-from abc import ABC,abstractmethod
+from abc import ABC, abstractmethod
+
+__author__ = "Mael Guilleme mael.guilleme[at]irisa.fr"
 
-__author__ = 'Mael Guilleme mael.guilleme[at]irisa.fr'
 
 class Transform(ABC):
     """
@@ -9,6 +10,7 @@ class Transform(ABC):
     Attributes:
         explained_instance (Object): instance to explain.
     """
+
     @abstractmethod
     def __init__(self, explained_instance):
         """
@@ -27,4 +29,4 @@ class Transform(ABC):
         Returns:
             neighbor_values (Object): representation of the neighbor in the data space of time series to explain.
         """
-        pass
\ No newline at end of file
+        pass
