@@ -1,9 +1,8 @@
-from . import base_model, PyTorchModel, SklearnModel, TensorflowModel
+from . import PyTorchModel, SklearnModel, TensorflowModel, base_model
 
 __all__ = [
     "base_model",
     "PyTorchModel",
     "SklearnModel",
     "TensorflowModel",
-   
-]
\ No newline at end of file
+]
