@@ -1,12 +1,10 @@
-import pickle
-from TSInterpret.constants import BackEndTypes
 from abc import ABC, abstractmethod
-import numpy as np 
 from typing import List
-class BaseModel(ABC):
 
-    def __init__(self, model=None, change= False,model_path='', backend='Func') -> None:
-        """Initialize Base Model. 
+
+class BaseModel(ABC):
+    def __init__(self, model=None, change=False, model_path="", backend="Func") -> None:
+        """Initialize Base Model.
         Arguments:
             model: trained ML Model, either the model or the direct function call for returning the probability distribution.
             change bool:  True if dimension change is necessary.
@@ -20,20 +18,21 @@ class BaseModel(ABC):
         self.backend = backend
 
     @abstractmethod
-    def load_model(self,path):
+    def load_model(self, path):
         """Loads the model provided at the given path.
         Arguments:
-            path str: Path to the trained model- 
+            path str: Path to the trained model-
          Returns:
             loaded model.
-        
+
         """
         pass
+
     @abstractmethod
-    def predict(self, item)-> List:
-        """ Unified prediction function.
+    def predict(self, item) -> List:
+        """Unified prediction function.
         Arguments:
-            item np.array: item to be classified 
+            item np.array: item to be classified
          Returns:
             an array of output scores for a classifier, and a singleton array of predicted value for a regressor.
         """
